@@ -80,7 +80,7 @@ class Client:
     @property
     def window_rectangle(self):
         """
-        Get this window's rectangle
+        Get this client's window rectangle
         """
         return get_window_rectangle(self.window_handle)
 
@@ -213,7 +213,7 @@ class Client:
     async def is_loading(self) -> bool:
         """
         If the client is currently in a loading screen
-        (does not apply to chacter load in)
+        (does not apply to character load in)
         """
         if not self._is_loading_addr:
             mov_instruction_addr = await self.hook_handler.pattern_scan(
